# Changelog

## [0.2.3a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.2.3a1) (2024-10-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.2.2a1...0.2.3a1)

**Merged pull requests:**

- fix:log\_spam [\#566](https://github.com/OpenVoiceOS/ovos-core/pull/566) ([JarbasAl](https://github.com/JarbasAl))

## [0.2.2a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.2.2a1) (2024-10-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.2.1...0.2.2a1)

**Merged pull requests:**

- deprecate ready setting [\#554](https://github.com/OpenVoiceOS/ovos-core/pull/554) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
